==> utox_0.17.0.orig.tar.gz: uTox-0.17.0/langs/de.h <==
/******************************************************************************
 *** German i18l Strings                                                    ***
 ******************************************************************************/
msgid(LANG_NATIVE_NAME)
msgstr("Deutsch")

msgid(LANG_ENGLISH_NAME)
msgstr("GERMAN")


/******************************************************************************
 *** UNSORTED STRINGS                                                       ***
 ******************************************************************************/
msgid(REQ_SENT)
msgstr("Freundschaftsanfrage verschickt. Dein Freund wird online erscheinen, sobald er deine Anfrage akzeptiert hat.")

msgid(REQ_INVALID_ID)
msgstr("Fehler: Ungültige Tox ID")

msgid(REQ_EMPTY_ID)
msgstr("Fehler: Keine Tox ID angegeben")

msgid(REQ_LONG_MSG)
msgstr("Fehler: Nachricht ist zu lang")

msgid(REQ_NO_MSG)
msgstr("Fehler: Leere Nachricht")

msgid(REQ_SELF_ID)
msgstr("Fehler: Tox ID ist eigene ID")

msgid(REQ_ALREADY_FRIENDS)
msgstr("Fehler: Tox ID ist bereits in der Freundesliste")

msgid(REQ_UNKNOWN)
msgstr("Fehler: Unbekannt")

msgid(REQ_BAD_CHECKSUM)
msgstr("Fehler: Ungültige Tox ID (ungültige Prüfsumme)")

msgid(REQ_BAD_NOSPAM)
msgstr("Fehler: Ungültige Tox ID (ungültiger NoSpam-Wert)")

msgid(REQ_NO_MEMORY)
msgstr("Fehler: Kein Speicher")

msgid(SEND_FILE)
msgstr("Datei senden")

msgid(SAVE_FILE)
msgstr("Datei speichern")

msgid(WHERE_TO_SAVE_FILE_PROMPT)
msgstr("Wo soll \"%.*s\" gespeichert werden?")

msgid(WHERE_TO_SAVE_FILE)
msgstr("Wo soll die Datei gespeichert werden?")

msgid(SEND_FILE_PROMPT)
msgstr("Wähle eine oder mehrere Dateien zum Senden.")

msgid(SCREEN_CAPTURE_PROMPT)
msgstr("Markiere den Bereich des Bildschirms, der gesendet werden soll.")


/******************************************************************************
 *** File Transfer Strings                                                  ***
 ******************************************************************************/
msgid(TRANSFER_NEW)
msgstr("Neue Dateiübertragung")

msgid(TRANSFER_STARTED)
msgstr("Dateiübertragung gestartet")

msgid(TRANSFER_PAUSED)
msgstr("Dateiübertragung pausiert")

msgid(TRANSFER_BROKEN)
msgstr("Dateiübertragung fehlerhaft")

msgid(TRANSFER_CANCELLED)
msgstr("Dateiübertragung abgebrochen")

msgid(TRANSFER_COMPLETE)
msgstr("Dateiübertragung abgeschlossen")


/******************************************************************************
 *** Keyboard and Mouse Cursor Strings                                      ***
 ******************************************************************************/
msgid(CURSOR_CLICK_LEFT)
msgstr("Linksklick")

msgid(CURSOR_CLICK_RIGHT)
msgstr("Rechtsklick")


/******************************************************************************
 *** Audio / Video Call Strings                                             ***
 ******************************************************************************/
msgid(CALL_START_AUDIO)
msgstr("Anruf beginnen")

msgid(CALL_START_VIDEO)
msgstr("Videoanruf beginnen")

msgid(CALL_DECLINE)
msgstr("Anruf ablehnen")

msgid(CALL_CANCELLED)
msgstr("Anruf abgebrochen")

msgid(CALL_INVITED)
msgstr("Anruf eingeladen")

msgid(CALL_RINGING)
msgstr("Anruf klingelt")

msgid(CALL_STARTED)
msgstr("Anruf gestartet")

msgid(CALL_FRIEND_HAD_ENDED_CALL)
msgstr(" hat den Anruf beendet!")

msgid(CALL_VIDEO_SHOW_INLINE)
msgstr("Video inline zeigen")


/******************************************************************************
 *** Friend & Friend Settings Strings                                       ***
 ******************************************************************************/
msgid(FRIEND_ALIAS)
msgstr("Alias setzen")

msgid(FRIEND_PUBLIC_KEY)
msgstr("Öffentlicher Schlüssel")

msgid(FRIEND_AUTOACCEPT)
msgstr("Eingehende Dateiübertragungen ohne Nachfrage akzeptieren")

msgid(FRIEND_EXPORT_CHATLOG)
msgstr("Chatverlauf als Text exportieren")


/******************************************************************************
 *** Group Strings                                                          ***
 ******************************************************************************/
msgid(GROUPCHAT_JOIN_AUDIO)
msgstr("Audiochat beitreten")

msgid(GROUP_CREATE_TEXT)
msgstr("Text-Gruppenchat erstellen")

msgid(GROUP_CREATE_VOICE)
msgstr("Audio-Gruppenchat erstellen")

msgid(CREATEGROUPCHAT)
msgstr("Gruppenchat erstellen")

msgid(REMOVE_GROUP)
msgstr("Gruppe entfernen")

msgid(LEAVE_GROUP)
msgstr("Gruppe verlassen")


/******************************************************************************
 *** Group Settings                                                         ***
 ******************************************************************************/
msgid(GROUPCHAT_SETTINGS)
msgstr("Gruppenchat-Einstellungen")

msgid(GROUP_NOTIFICATIONS)
msgstr("Benachrichtigungen")

msgid(GROUP_NOTIFICATIONS_ON)
msgstr("An")

msgid(GROUP_NOTIFICATIONS_MENTION)
msgstr("Erwähnung")

msgid(GROUP_NOTIFICATIONS_OFF)
msgstr("Aus")

msgid(GROUP_TOPIC)
msgstr("Thema der Gruppe festlegen")

/******************************************************************************
 *** Settings / Profile Strings                                             ***
 ******************************************************************************/
msgid(PROFILE_BUTTON)
msgstr("Profil")

msgid(DEVICES_BUTTON)
msgstr("Geräte")


msgid(USER_INTERFACE_BUTTON)
msgstr("Benutzeroberfläche")

msgid(AUDIO_VIDEO_BUTTON)
msgstr("Audio & Video")

msgid(ADVANCED_BUTTON)
msgstr("Fortgeschritten")

msgid(NOTIFICATIONS_BUTTON)
msgstr("Benachrichtigungen")

msgid(AUTO_UPDATE)
msgstr("uTox automatisch aktualisieren")

msgid(PROFILE_SETTINGS)
msgstr("Profileinstellungen")

msgid(PROFILE_PW_WARNING)
msgstr("WARNUNG: µTox wird automatisch beginnen mit diesem Passwort zu verschlüsseln.")

msgid(PROFILE_PW_NO_RECOVER)
msgstr("Es ist nicht möglich verlorene Passwörter wiederherzustellen.")



/***     	Profile                                                         ***/

/***     	Devices                                                       ***/
msgid(DEVICES_ADD_NEW)
msgstr("Neues Gerät hinzufügen")

msgid(DEVICES_NUMBER)
msgstr("Anzahl der verknüpften Geräte")
/*** 		Network                                                         ***/

/***    User Interface                                                  ***/

/***		Audio/Video                                                     ***/


/******************************************************************************
 *** UNSORTED STRINGS                                                       ***
 ******************************************************************************/
msgid(ADDFRIENDS)
msgstr("Neuen Kontakt hinzufügen")

msgid(TOXID)
msgstr("Tox ID")

msgid(MESSAGE)
msgstr("Nachricht")

msgid(FILTER_ONLINE)
msgstr("Online")

msgid(FILTER_ALL)
msgstr("Alle")

msgid(FILTER_CONTACT_TOGGLE)
msgstr("Filterung von offline Kontakten umschalten.")

msgid(ADD)
msgstr("Hinzufügen")

msgid(FRIENDREQUEST)
msgstr("Freundschaftsanfrage")

msgid(USERSETTINGS)
msgstr("Benutzereinstellungen")

msgid(FRIEND_SETTINGS)
msgstr("Freundeinstellungen")

msgid(STATUSMESSAGE)
msgstr("Statusnachricht")

msgid(PREVIEW)
msgstr("Vorschau")

msgid(AUDIOINPUTDEVICE)
msgstr("Audioeingabegerät")

msgid(AUDIOFILTERING)
msgstr("Audio filtern")

msgid(AUDIOOUTPUTDEVICE)
msgstr("Audioausgabegerät")

msgid(VIDEOINPUTDEVICE)
msgstr("Videoeingabegerät")

msgid(STATUS_AWAY)
msgstr("Abwesend")

msgid(STATUS_BUSY)
msgstr("Beschäftigt")

msgid(SETTINGS_UI_MINI_ROSTER)
msgstr("Kompakte Kontaktliste verwenden")

msgid(SETTINGS_UI_AUTO_HIDE_SIDEBAR)
msgstr("Seitenleiste automatisch verstecken")

msgid(NOT_CONNECTED)
msgstr("Nicht verbunden")

msgid(NOT_CONNECTED_SETTINGS)
msgstr("Netzwerk Einstellungen anpassen")

msgid(OTHERSETTINGS)
msgstr("Andere Einstellungen")

msgid(UI)
msgstr("Benutzeroberfläche")

msgid(USER_INTERFACE)
msgstr("Oberfläche") // "Benutzeroberfläche" doesn't fit into tab header (Settings)

msgid(UTOX_SETTINGS)
msgstr("Einstellungen") // "uTox Einstellungen" would overlap with version (Settings)

msgid(NETWORK_SETTINGS)
msgstr("Netzwerkeinstellungen")

msgid(PROFILE_PASSWORD)
msgstr("Profilpasswort")

msgid(LOCK_UTOX)
msgstr("Trennt die Verbindung zu Tox und sperrt dieses Profil.")

msgid(SHOW_UI_PASSWORD)
msgstr("Passwortfeld anzeigen")

msgid(SHOW_UI_PASSWORD_TOOLTIP)
msgstr("Hier klicken, um Passwortfeld anzuzeigen. Änderungen werden sofort angewendet!")

msgid(HIDE_UI_PASSWORD)
msgstr("Passwortfeld verstecken")

msgid(HIDE_UI_PASSWORD_TOOLTIP)
msgstr("Hier klicken, um Passwortfeld zu verstecken.")

msgid(LOCK)
msgstr("Sperren")

msgid(SAVELOCATION)
msgstr("Speichere Standorteinstellung")

msgid(LANGUAGE)
msgstr("Sprache")

msgid(NETWORK)
msgstr("Netzwerk")

msgid(PROXY_FORCE)
msgstr("Verwendung des Proxy's erzwingen")

msgid(WARNING)
msgstr("Das Verändern von Netzwerk-/Proxy-Einstellungen unterbricht die Verbindung zum Tox-Netzwerk.")

msgid(SAVE_CHAT_HISTORY)
msgstr("Chatverläufe speichern")

msgid(AUDIONOTIFICATIONS)
msgstr("Akustische Benachrichtigungen einschalten (Klingelton)")

msgid(RINGTONE)
msgstr("Klingelton")

msgid(IS_TYPING)
msgstr("schreibt ...")

msgid(CLOSE_TO_TRAY)
msgstr("In den Infobereich schließen")

msgid(START_IN_TRAY)
msgstr("Im Infobereich starten")

msgid(COPY)
msgstr("Kopieren")

msgid(COPYWITHOUTNAMES)
msgstr("Kopieren (ohne Namen)")

msgid(COPY_WITH_NAMES)
msgstr("Kopieren (mit Namen)")

msgid(CUT)
msgstr("Ausschneiden")

msgid(PASTE)
msgstr("Einfügen")

msgid(DELETE)
msgstr("Löschen")

msgid(SELECTALL)
msgstr("Alle auswählen")

msgid(REMOVE)
msgstr("Entfernen")

msgid(REMOVE_FRIEND)
msgstr("Freund entfernen")

msgid(LEAVE)
msgstr("Verlassen")

msgid(CTOPIC)
msgstr("Thema ändern")

msgid(ACCEPT)
msgstr("Akzeptieren")

msgid(IGNORE)
msgstr("Ignorieren")

msgid(SET_ALIAS)
msgstr("Alias setzen")

msgid(SENDMESSAGE)
msgstr("Senden")

msgid(SENDSCREENSHOT)
msgstr("Bildschirmaufnahme senden")

msgid(CLICKTOSAVE)
msgstr("Klicken um zu speichern")

msgid(CLICKTOOPEN)
msgstr("Klicken um zu öffnen")

msgid(CANCELLED)
msgstr("Abgebrochen")

msgid(DPI_TINY)
msgstr("Klein (50%)")

msgid(DPI_BIG)
msgstr("Groß (150%)")

msgid(DPI_LARGE)
msgstr("Größer (200%)")

msgid(DPI_HUGE)
msgstr("Sehr groß (250%)")

msgid(PROXY_DISABLED)
msgstr("Deaktiviert")

msgid(PROXY_ALWAYS_USE)
msgstr("Immer benutzen")

msgid(NO)
msgstr("Nein")

msgid(YES)
msgstr("Ja")

msgid(OFF)
msgstr("Aus")

msgid(ON)
msgstr("An")

msgid(SHOW)
msgstr("Zeigen")

msgid(HIDE)
msgstr("Verstecken")

msgid(VIDEO_IN_NONE)
msgstr("keines")

msgid(AUDIO_IN_DEFAULT_LOOPBACK)
msgstr("Standard Loopback")

msgid(AUDIO_IN_ANDROID)
msgstr("OpenSL-Eingang")

msgid(DEFAULT_FRIEND_REQUEST_MESSAGE)
msgstr("Bitte füge mich deiner Kontaktliste hinzu.")

msgid(CONTACT_SEARCH_ADD_HINT)
msgstr("Freunde suchen/hinzufügen")

msgid(WINDOW_TITLE_VIDEO_PREVIEW)
msgstr("Videovorschau")

msgid(MUTE)
msgstr("Stummschalten")

msgid(UNMUTE)
msgstr("Stummschaltung aufheben")

msgid(SELECT_AVATAR_TITLE)
msgstr("Avatar auswählen")

msgid(AVATAR_TOO_LARGE_MAX_SIZE_IS)
msgstr("Avatar zu groß. Maximale Größe: ")

msgid(CANT_FIND_FILE_OR_EMPTY)
msgstr("Ausgewählte Datei existiert nicht oder ist leer.")

msgid(CLEAR_HISTORY)
msgstr("Chatverlauf leeren")

msgid(AUTO_STARTUP)
msgstr("Automatisch beim Systemstart starten")

msgid(THEME)
msgstr("Stil")

msgid(THEME_DEFAULT)
msgstr("Standard")

msgid(THEME_LIGHT)
msgstr("Hell")

msgid(THEME_DARK)
msgstr("Dunkel")

msgid(THEME_HIGHCONTRAST)
msgstr("Hoher Kontrast")

msgid(THEME_CUSTOM)
msgstr("Benutzerdefiniert (siehe Dokumentation)")

msgid(THEME_SOLARIZED_LIGHT)
msgstr("Solarized hell")

msgid(THEME_SOLARIZED_DARK)
msgstr("Solarized dunkel")

msgid(SEND_TYPING_NOTIFICATIONS)
msgstr("Mitteilen, ob getippt wird")

msgid(STATUS_NOTIFICATIONS)
msgstr("Statusbenachrichtigungen")

msgid(RANDOMIZE_NOSPAM)
msgstr("Zufälligen Nospam setzen")

msgid(NOSPAM)
msgstr("Nospam")

msgid(REVERT_NOSPAM)
msgstr("Nospam zurücksetzen")

msgid(NOSPAM_WARNING)
msgstr("Änderungen am Nospam machen die alte Tox ID ungültig. uTox wird die ID nicht auf Namensservern aktualisieren.")

msgid(BLOCK_FRIEND_REQUESTS)
msgstr("Freundschaftsanfragen blockieren")

msgid(SHOW_NOSPAM)
msgstr("Nospam Einstellungen anzeigen")

msgid(HIDE_NOSPAM)
msgstr("Nospam Einstellungen verstecken")

msgid(DELETE_FRIEND)
msgstr("Freund löschen")

msgid(KEEP)
msgstr("Behalten")

==> utox_0.17.1.orig.tar.gz: uTox-0.17.1/langs/de.h <==
/******************************************************************************
 *** German i18l Strings                                                    ***
 ******************************************************************************/
msgid(LANG_NATIVE_NAME)
msgstr("Deutsch")

msgid(LANG_ENGLISH_NAME)
msgstr("GERMAN")


/******************************************************************************
 *** MISC & UNSORTED                                                        ***
 ******************************************************************************/
msgid(REQ_SENT)
msgstr("Freundschaftsanfrage verschickt. Dein Freund wird online erscheinen, sobald er deine Anfrage akzeptiert hat.")

msgid(REQ_INVALID_ID)
msgstr("Fehler: Ungültige Tox ID")

msgid(REQ_EMPTY_ID)
msgstr("Fehler: Keine Tox ID angegeben")

msgid(REQ_LONG_MSG)
msgstr("Fehler: Nachricht ist zu lang")

msgid(REQ_NO_MSG)
msgstr("Fehler: Leere Nachricht")

msgid(REQ_SELF_ID)
msgstr("Fehler: Tox ID ist eigene ID")

msgid(REQ_ALREADY_FRIENDS)
msgstr("Fehler: Tox ID ist bereits in der Freundesliste")

msgid(REQ_UNKNOWN)
msgstr("Fehler: Unbekannt")

msgid(REQ_BAD_CHECKSUM)
msgstr("Fehler: Ungültige Tox ID (ungültige Prüfsumme)")

msgid(REQ_BAD_NOSPAM)
msgstr("Fehler: Ungültige Tox ID (ungültiger NoSpam-Wert)")

msgid(REQ_NO_MEMORY)
msgstr("Fehler: Kein Speicher")

msgid(SEND_FILE)
msgstr("Datei senden")

msgid(SAVE_FILE)
msgstr("Datei speichern")

msgid(WHERE_TO_SAVE_FILE_PROMPT)
msgstr("Wo soll \"%.*s\" gespeichert werden?")

msgid(WHERE_TO_SAVE_FILE)
msgstr("Wo soll die Datei gespeichert werden?")

msgid(SEND_FILE_PROMPT)
msgstr("Wähle eine oder mehrere Dateien zum Senden.")

msgid(SCREEN_CAPTURE_PROMPT)
msgstr("Markiere den Bereich des Bildschirms, der gesendet werden soll.")


/******************************************************************************
 *** File Transfer Strings                                                  ***
 ******************************************************************************/
msgid(TRANSFER_NEW)
msgstr("Neue Dateiübertragung")

msgid(TRANSFER_STARTED)
msgstr("Dateiübertragung gestartet")

msgid(TRANSFER_PAUSED)
msgstr("Dateiübertragung pausiert")

msgid(TRANSFER_BROKEN)
msgstr("Dateiübertragung fehlerhaft")

msgid(TRANSFER_CANCELLED)
msgstr("Dateiübertragung abgebrochen")

msgid(TRANSFER_COMPLETE)
msgstr("Dateiübertragung abgeschlossen")


/******************************************************************************
 *** Keyboard and Mouse Cursor Strings                                      ***
 ******************************************************************************/
msgid(CURSOR_CLICK_LEFT)
msgstr("Linksklick")

msgid(CURSOR_CLICK_RIGHT)
msgstr("Rechtsklick")


/******************************************************************************
 *** Audio / Video Call Strings                                             ***
 ******************************************************************************/
msgid(CALL_START_AUDIO)
msgstr("Anruf beginnen")

msgid(CALL_START_VIDEO)
msgstr("Videoanruf beginnen")

msgid(CALL_DECLINE)
msgstr("Anruf ablehnen")

msgid(CALL_CANCELLED)
msgstr("Anruf abgebrochen")

msgid(CALL_INVITED)
msgstr("Anruf eingeladen")

msgid(CALL_RINGING)
msgstr("Anruf klingelt")

msgid(CALL_STARTED)
msgstr("Anruf gestartet")

msgid(CALL_FRIEND_HAD_ENDED_CALL)
msgstr(" hat den Anruf beendet!")

msgid(CALL_VIDEO_SHOW_INLINE)
msgstr("Video inline zeigen")


/******************************************************************************
 *** Friend & Friend Settings Strings                                       ***
 ******************************************************************************/
msgid(FRIEND_ALIAS)
msgstr("Alias setzen")

msgid(FRIEND_PUBLIC_KEY)
msgstr("Öffentlicher Schlüssel")

msgid(FRIEND_AUTOACCEPT)
msgstr("Eingehende Dateiübertragungen ohne Nachfrage akzeptieren")

msgid(FRIEND_EXPORT_CHATLOG)
msgstr("Chatverlauf als Text exportieren")


/******************************************************************************
 *** Group Strings                                                          ***
 ******************************************************************************/
msgid(GROUPCHAT_JOIN_AUDIO)
msgstr("Audiochat beitreten")

msgid(GROUP_CREATE_WITH_AUDIO)
msgstr("Audio aktivieren")

msgid(GROUP_CREATE_TEXT)
msgstr("Text-Gruppenchat erstellen")

msgid(GROUP_CREATE_VOICE)
msgstr("Audio-Gruppenchat erstellen")

msgid(CREATEGROUPCHAT)
msgstr("Gruppenchat erstellen")

msgid(REMOVE_GROUP)
msgstr("Gruppe entfernen")

msgid(LEAVE_GROUP)
msgstr("Gruppe verlassen")


/******************************************************************************
 *** Group Settings                                                         ***
 ******************************************************************************/
msgid(GROUPCHAT_SETTINGS)
msgstr("Gruppenchat-Einstellungen")

msgid(GROUP_NOTIFICATIONS)
msgstr("Gruppenbenachrichtigungen")

msgid(GROUP_NOTIFICATIONS_ON)
msgstr("An")

msgid(GROUP_NOTIFICATIONS_MENTION)
msgstr("Erwähnung")

msgid(GROUP_NOTIFICATIONS_OFF)
msgstr("Aus")

msgid(GROUP_TOPIC)
msgstr("Thema der Gruppe festlegen")

/******************************************************************************
 *** Settings / Profile Strings                                             ***
 ******************************************************************************/
msgid(PROFILE_BUTTON)
msgstr("Profil")

msgid(DEVICES_BUTTON)
msgstr("Geräte")


msgid(USER_INTERFACE_BUTTON)
msgstr("Benutzeroberfläche")

msgid(AUDIO_VIDEO_BUTTON)
msgstr("Audio & Video")

msgid(ADVANCED_BUTTON)
msgstr("Fortgeschritten")

msgid(NOTIFICATIONS_BUTTON)
msgstr("Benachrichtigungen")

msgid(AUTO_UPDATE)
msgstr("uTox automatisch aktualisieren")

msgid(PROFILE_SETTINGS)
msgstr("Profileinstellungen")

msgid(PROFILE_PW_WARNING)
msgstr("WARNUNG: µTox wird automatisch beginnen mit diesem Passwort zu verschlüsseln.")

msgid(PROFILE_PW_NO_RECOVER)
msgstr("Es ist nicht möglich verlorene Passwörter wiederherzustellen.")



/***     	Profile                                                         ***/

/***     	Devices                                                       ***/
msgid(DEVICES_ADD_NEW)
msgstr("Neues Gerät hinzufügen")

msgid(DEVICES_NUMBER)
msgstr("Anzahl der verknüpften Geräte")
/*** 		Network                                                         ***/

/***    User Interface                                                  ***/

/***		Audio/Video                                                     ***/


/******************************************************************************
 *** UNSORTED STRINGS                                                       ***
 ******************************************************************************/
msgid(ADDFRIENDS)
msgstr("Neuen Kontakt hinzufügen")

msgid(TOXID)
msgstr("Tox ID")

msgid(MESSAGE)
msgstr("Nachricht")

msgid(FILTER_ONLINE)
msgstr("Online")

msgid(FILTER_ALL)
msgstr("Alle")

msgid(FILTER_CONTACT_TOGGLE)
msgstr("Filterung von offline Kontakten umschalten.")

msgid(ADD)
msgstr("Hinzufügen")

msgid(FRIENDREQUEST)
msgstr("Freundschaftsanfrage")

msgid(USERSETTINGS)
msgstr("Benutzereinstellungen")

msgid(FRIEND_SETTINGS)
msgstr("Freundeinstellungen")

msgid(STATUSMESSAGE)
msgstr("Statusnachricht")

msgid(PREVIEW)
msgstr("Vorschau")

msgid(AUDIOINPUTDEVICE)
msgstr("Audioeingabegerät")

msgid(AUDIOFILTERING)
msgstr("Audio filtern")

msgid(AUDIOOUTPUTDEVICE)
msgstr("Audioausgabegerät")

msgid(VIDEOINPUTDEVICE)
msgstr("Videoeingabegerät")

msgid(STATUS_AWAY)
msgstr("Abwesend")

msgid(STATUS_BUSY)
msgstr("Beschäftigt")

msgid(SETTINGS_UI_MINI_ROSTER)
msgstr("Kompakte Kontaktliste verwenden")

msgid(SETTINGS_UI_AUTO_HIDE_SIDEBAR)
msgstr("Seitenleiste automatisch verstecken")

msgid(NOT_CONNECTED)
msgstr("Nicht verbunden")

msgid(NOT_CONNECTED_SETTINGS)
msgstr("Netzwerk Einstellungen anpassen")

msgid(OTHERSETTINGS)
msgstr("Andere Einstellungen")

msgid(UI)
msgstr("Benutzeroberfläche")

msgid(USER_INTERFACE)
msgstr("Oberfläche") // "Benutzeroberfläche" doesn't fit into tab header (Settings)

msgid(UTOX_SETTINGS)
msgstr("Einstellungen") // "uTox Einstellungen" would overlap with version (Settings)

msgid(NETWORK_SETTINGS)
msgstr("Netzwerkeinstellungen")

msgid(PROFILE_PASSWORD)
msgstr("Profilpasswort")

msgid(LOCK_UTOX)
msgstr("Trennt die Verbindung zu Tox und sperrt dieses Profil.")

msgid(SHOW_UI_PASSWORD)
msgstr("Passwortfeld anzeigen")

msgid(SHOW_UI_PASSWORD_TOOLTIP)
msgstr("Hier klicken, um Passwortfeld anzuzeigen. Änderungen werden sofort angewendet!")

msgid(HIDE_UI_PASSWORD)
msgstr("Passwortfeld verstecken")

msgid(HIDE_UI_PASSWORD_TOOLTIP)
msgstr("Hier klicken, um Passwortfeld zu verstecken.")

msgid(PASSWORD_TOO_SHORT)
msgstr("Passwort muss mindestens 4 Zeichen lang sein")

msgid(LOCK)
msgstr("Sperren")

msgid(SAVELOCATION)
msgstr("Speichere Standorteinstellung")

msgid(LANGUAGE)
msgstr("Sprache")

msgid(NETWORK)
msgstr("Netzwerk")

msgid(PROXY_FORCE)
msgstr("Verwendung des Proxys erzwingen")

msgid(WARNING)
msgstr("Das Verändern von Netzwerk-/Proxy-Einstellungen unterbricht kurzzeitig die Verbindung zum Tox-Netzwerk.")

msgid(SAVE_CHAT_HISTORY)
msgstr("Chatverläufe speichern")

msgid(AUDIONOTIFICATIONS)
msgstr("Akustische Benachrichtigungen einschalten (Klingelton)")

msgid(RINGTONE)
msgstr("Klingelton")

msgid(IS_TYPING)
msgstr("schreibt ...")

msgid(CLOSE_TO_TRAY)
msgstr("In den Infobereich schließen")

msgid(START_IN_TRAY)
msgstr("Im Infobereich starten")

msgid(SHOW_QR)
msgstr("QR Code anzeigen")

msgid(HIDE_QR)
msgstr("QR Code verstecken")

msgid(SAVE_QR)
msgstr("QR Code speichern")

msgid(COPY_TOX_ID)
msgstr("Kopieren")

msgid(COPY)
msgstr("Kopieren")

msgid(COPYWITHOUTNAMES)
msgstr("Kopieren (ohne Namen)")

msgid(COPY_WITH_NAMES)
msgstr("Kopieren (mit Namen)")

msgid(CUT)
msgstr("Ausschneiden")

msgid(PASTE)
msgstr("Einfügen")

msgid(DELETE)
msgstr("Löschen")

msgid(SELECTALL)
msgstr("Alles markieren")

msgid(REMOVE)
msgstr("Entfernen")

msgid(REMOVE_FRIEND)
msgstr("Freund entfernen")

msgid(LEAVE)
msgstr("Verlassen")

msgid(CTOPIC)
msgstr("Thema ändern")

msgid(ACCEPT)
msgstr("Akzeptieren")

msgid(IGNORE)
msgstr("Ignorieren")

msgid(SET_ALIAS)
msgstr("Alias setzen")

msgid(SENDMESSAGE)
msgstr("Senden")

msgid(SENDSCREENSHOT)
msgstr("Bildschirmfoto senden")

msgid(CLICKTOSAVE)
msgstr("Klicken um zu speichern")

msgid(CLICKTOOPEN)
msgstr("Klicken um zu öffnen")

msgid(CANCELLED)
msgstr("Abgebrochen")

msgid(DPI_TINY)
msgstr("Klein (50%)")

msgid(DPI_BIG)
msgstr("Groß (150%)")

msgid(DPI_LARGE)
msgstr("Größer (200%)")

msgid(DPI_HUGE)
msgstr("Sehr groß (250%)")

msgid(PROXY_DISABLED)
msgstr("Deaktiviert")

msgid(PROXY_ALWAYS_USE)
msgstr("Immer benutzen")

msgid(NO)
msgstr("Nein")

msgid(YES)
msgstr("Ja")

msgid(OFF)
msgstr("Aus")

msgid(ON)
msgstr("An")

msgid(SHOW)
msgstr("Zeigen")

msgid(HIDE)
msgstr("Verstecken")

msgid(EXIT)
msgstr("Beenden")

msgid(VIDEO_IN_NONE)
msgstr("keines")

msgid(AUDIO_IN_DEFAULT_LOOPBACK)
msgstr("Standard Loopback")

msgid(AUDIO_IN_ANDROID)
msgstr("OpenSL-Eingang")

msgid(DEFAULT_FRIEND_REQUEST_MESSAGE)
msgstr("Bitte füge mich deiner Kontaktliste hinzu.")

msgid(CONTACT_SEARCH_ADD_HINT)
msgstr("Freunde suchen/hinzufügen")

msgid(PROXY_EDIT_HINT_IP)
msgstr("IP-Adresse")

msgid(WINDOW_TITLE_VIDEO_PREVIEW)
msgstr("Videovorschau")

msgid(MUTE)
msgstr("Stummschalten")

msgid(UNMUTE)
msgstr("Stummschaltung aufheben")

msgid(SELECT_AVATAR_TITLE)
msgstr("Avatar auswählen")

msgid(AVATAR_TOO_LARGE_MAX_SIZE_IS)
msgstr("Avatar zu groß. Maximale Größe: ")

msgid(CANT_FIND_FILE_OR_EMPTY)
msgstr("Ausgewählte Datei existiert nicht oder ist leer.")

msgid(CLEAR_HISTORY)
msgstr("Chatverlauf leeren")

msgid(AUTO_STARTUP)
msgstr("Automatisch beim Systemstart starten")

msgid(THEME)
msgstr("Stil")

msgid(THEME_DEFAULT)
msgstr("Standard")

msgid(THEME_LIGHT)
msgstr("Hell")

msgid(THEME_DARK)
msgstr("Dunkel")

msgid(THEME_HIGHCONTRAST)
msgstr("Hoher Kontrast")

msgid(THEME_CUSTOM)
msgstr("Benutzerdefiniert (siehe Dokumentation)")

msgid(THEME_SOLARIZED_LIGHT)
msgstr("Solarized hell")

msgid(THEME_SOLARIZED_DARK)
msgstr("Solarized dunkel")

msgid(SEND_TYPING_NOTIFICATIONS)
msgstr("Mitteilen, ob getippt wird")

msgid(STATUS_NOTIFICATIONS)
msgstr("Statusbenachrichtigungen")

msgid(RANDOMIZE_NOSPAM)
msgstr("Zufälligen Nospam setzen")

msgid(NOSPAM)
msgstr("Nospam")

msgid(REVERT_NOSPAM)
msgstr("Nospam zurücksetzen")

msgid(NOSPAM_WARNING)
msgstr("Änderungen am Nospam machen die alte Tox ID ungültig. uTox wird die ID nicht auf Namensservern aktualisieren.")

msgid(BLOCK_FRIEND_REQUESTS)
msgstr("Freundschaftsanfragen blockieren")

msgid(SHOW_NOSPAM)
msgstr("Nospam Einstellungen anzeigen")

msgid(HIDE_NOSPAM)
msgstr("Nospam Einstellungen verstecken")

msgid(DELETE_FRIEND)
msgstr("Freund löschen")

msgid(KEEP)
msgstr("Behalten")
